Aglyph 1.1.1 testing summary — Aglyph 3.0.0 documentation

# Aglyph 1.1.1 testing summary

Warning

Changed in version 1.1.1.

The Python 3.0 lifespan has ended; the Aglyph test suite is no longer executed under this version.

## CPython

Version | Platform
--- | ---
2.5.4 | Windows-Vista-6.1.7601 MSC v.1310 32 bit
2.5.6 | Darwin-10.8.0-i386-64bit GCC 4.2.1 (Apple Inc. build 5646) (dot 1)
2.6.6 | Windows-7-6.1.7601-SP1 MSC v.1500 32 bit
2.6.8 | Darwin-10.8.0-i386-64bit GCC 4.2.1 (Apple Inc. build 5646) (dot 1)
2.7.3 | Windows-7-6.1.7601-SP1 MSC v.1500 32 bit
| Darwin-10.8.0-i386-64bit GCC 4.2.1 (Apple Inc. build 5666) (dot 3)
3.1.4 | Windows-7-6.1.7601-SP1 MSC v.1500 32 bit
3.1.5 | Darwin-10.8.0-i386-64bit GCC 4.2.1 (Apple Inc. build 5646) (dot 1)
3.2.3 | Windows-7-6.1.7601-SP1 MSC v.1500 32 bit
| Darwin-10.8.0-i386-64bit GCC 4.2.1 (Apple Inc. build 5646) (dot 1)
3.3.0 | Windows-7-6.1.7601-SP1 MSC v.1600 32 bit
| Darwin-10.8.0-i386-64bit GCC 4.2.1 (Apple Inc. build 5666) (dot 3)

## PyPy

Version | Platform
--- | ---
1.9 (2.7.2) | Windows-7-6.1.7601-SP1 32 bit
| Darwin-10.8.0-i386-64bit

## Stackless Python

Version | Platform
--- | ---
2.7.2 (3.1b3 060516) | Windows-7-6.1.7601-SP1 MSC v.1500 32 bit
| Darwin-10.8.0-i386-64bit GCC 4.2.1 (Apple Inc. build 5646) (dot 1)
3.2.2 (3.1b3 060516) | Windows-7-6.1.7601-SP1 MSC v.1500 32 bit
| Darwin-10.8.0-i386-64bit GCC 4.2.1 (Apple Inc. build 5646) (dot 1)

## IronPython

Version | Platform
--- | ---
2.7.3 | Windows-7-6.1.7601-SP1 cli-32bit .NET 4.0.30319.296 (32-bit)

## Jython

Version | Platform
--- | ---
2.5.3 | Java-1.7.0_17-Java_HotSpot-TM-_Client_VM,_23.7-b01,_Oracle_Corporation-on-Windows_7-6.1-x86 Java HotSpot(TM) Client VM (Oracle Corporation)
| Java-1.6.0_43-Java_HotSpot-TM-_64-Bit_Server_VM,_20.14-b01-447,_Apple_Inc.-on-Mac_OS_X-10.6.8-x86_64 Java HotSpot(TM) 64-Bit Server VM (Apple Inc.)